@@ -10,14 +10,13 @@ use Config;
 use File::Spec::Functions qw( catdir catfile );
 use File::Copy qw( move );
 use File::Path;
-use ExtUtils::MakeMaker qw( prompt );   # Module::Build's prompt sucks
 use base qw( Module::Build );
 use strict;
 use warnings;
 
 use vars qw( $VERSION $TRUE $FALSE );
 BEGIN {
-    $VERSION = '0.02_02';
+    $VERSION = '0.01';
 }
 *TRUE  = \1;
 *FALSE = \0;
@@ -26,17 +25,12 @@ BEGIN {
 ### Variables
 #########################################################################
 
-our $DEF_SWIG_VERSION = '2.0.1';
-
 my $SWIG             = 'swig';
-my $BASE_DL_URL      = 'http://downloads.sourceforge.net/swig/';
-my $SWIG_VER_FILE    = 'swig_build_version';
+my $DEF_SWIG_VERSION = '2.0.1';
 
-# Weighted list: 2.0.1 will be tested 1/3 of the time, ~4.762% for others
 my @known_vers = qw(
     1.3.28  1.3.29  1.3.30  1.3.31  1.3.32  1.3.33  1.3.34  1.3.35
-    1.3.36  1.3.37  1.3.38  1.3.39  1.3.40  2.0.0
-    2.0.1   2.0.1   2.0.1   2.0.1   2.0.1   2.0.1   2.0.1
+    1.3.36  1.3.37  1.3.38  1.3.39  1.3.40  2.0.0   2.0.1
 );
 my %known_vers = ();    # mapped on demand
 
@@ -59,9 +53,12 @@ sub ACTION_code {
     $self->SUPER::ACTION_code;
     $|=1;
 
+    # See if we passed a different SWIG ver in during Build script creation
+    $self->{'properties'}->{'swig_version'} = $DEF_SWIG_VERSION
+        unless( exists( $self->{'properties'}->{'swig_version'} ) );
+
     # Build the package
-    $self->fetch_swig()
-        or $self->ask_to_try_again();
+    $self->fetch_swig();
     $self->extract_swig();
     $self->config_swig();
     $self->build_swig();
@@ -76,7 +73,7 @@ sub def_swig_ver {
 sub swig_ver {
     my $self = shift;
 
-    return $self->read_swig_ver();
+    return $self->get_mb_property( 'swig_version' );
 }
 
 sub swig_plus_ver {
@@ -109,45 +106,22 @@ sub swig_ver_file {
 
 sub swig_url {
     my $self = shift;
-    return $BASE_DL_URL . $self->swig_archive();
-}
-
-# I think some CPANTesters (wisely) filter net access during testing.
-sub ask_to_try_again
-{
-    my $self = shift;
-
-    if( $self->swig_ver() ne $self->def_swig_ver() )
-    {
-        my $ans = prompt( sprintf( "Trouble downloading SWIG v%s; install" .
-                                   " included %s version?",
-                                   $self->swig_ver(),
-                                   $self->def_swig_ver() ), 'yes' );
-        if( $ENV{AUTOMATED_TESTING} or $ans =~ m/y/i )
-        {
-            # Frobnicate the version file
-            $self->write_swig_ver_file( $self->def_swig_ver() );
-            print "\n";
-            return( $self->fetch_swig() );
-        }
-    }
-
-    die sprintf( "Couldn't download SWIG v%s; cannot continue.",
-                 $self->swig_ver() );
+    return 'http://prdownloads.sourceforge.net/swig/'
+            . $self->swig_archive();
 }
 
 sub fetch_swig {
     my $self = shift;
 
     # make-like simple check to see if we're done already
-    return $TRUE if( -f $self->swig_archive() );
+    return if( -f $self->swig_archive() );
 
     print 'Local copy of ', $self->swig_archive(), " not found.\n";
     print 'GET ', $self->swig_url(), '... ';
 
     # Grab the file
     require HTTP::Tiny;
-    my $http = HTTP::Tiny->new( timeout => 30 );
+    my $http = HTTP::Tiny->new();
     my $response = $http->get(
         $self->swig_url(),
         {
@@ -160,16 +134,13 @@ sub fetch_swig {
 
     unless( $response->{success} )
     {
-        my $content = ( exists( $response->{content} ) and
+        warn sprintf( "\nUnable to fetch archive: %s %s; Content was%s\n",
+                      $response->{status}, $response->{reason},
+                      ( exists( $response->{content} ) and
                         defined( $response->{content} ) and
                         length( $response->{content} ) )
-                          ? substr( $response->{content}, 0, 8*1024 )
-                          : "empty";
-        chomp $content;
-        warn sprintf( "\nUnable to fetch archive: %s %s; Content was%s\n",
-               $response->{status}, $response->{reason},
-               ":\n'" . $content . "'\n" );
-
+                          ? ":\n'" . $response->{content} . "'\n"
+                          : " empty.\n" );
         warn sprintf( <<'MOCK_THE_USER',
 You specified SWIG version '%s', which is not a known working version.
 
@@ -186,7 +157,7 @@ MOCK_THE_USER
                       $self->get_mb_property( 'swig_version' ),
                       $self->formatted_known_vers )
             unless( $self->is_known_ver( $self->swig_ver() ) );
-        return $FALSE;
+        die '';
     }
 
 
@@ -200,8 +171,6 @@ MOCK_THE_USER
     close( $fd );
 
     print "OK\n";
-
-    return $TRUE;
 }
 
 sub extract_swig {
@@ -424,21 +393,7 @@ sub my_system
                      ( $rv & 128 ) ? 'with' : 'without' );
     }
     elsif( ( $rv >> 8 ) > 0 ) {
-        # XXX: Remove this after figuring out what's going on w/ Ticket #39 ?
-        if( $^O =~ /Solaris/i )
-        {
-            printf( "SYSTEM: cmd '%s': FAIL (rv %d)\n", $_[0], $rv >> 8 );
-            print "Solaris detected; dumping Makefile:\n-----------\n";
-            my $cwd = getcwd();
-            open my $fh, '<', 'Makefile' or die "Can't open $cwd/Makefile: $!";
-            print $_ while( <$fh> );
-            close( $fh );
-            die "\n----------\nCannot continue with broken Makefile.\n";
-        }
-        else
-        {
-            die sprintf( "SYSTEM: cmd '%s': FAIL (rv %d)\n", $_[0], $rv >> 8 );
-        }
+        die sprintf( "SYSTEM: cmd '%s': FAIL (rv %d)\n", $_[0], $rv >> 8 );
     }
     else {
         printf( "SYSTEM: cmd '%s': OK (rv %d)\n", $_[0], $rv >> 8 );
@@ -472,18 +427,14 @@ sub create_ver_file {
     return;
 }
 
-# XXX: See these post on the swig-user mailing list for why this is here:
-# https://sourceforge.net/mailarchive/message.php?msg_id=26967542
-# https://sourceforge.net/mailarchive/message.php?msg_id=26978599
+# XXX: See this post on the swig-user mailing list for why this is here:
+# https://sourceforge.net/mailarchive/forum.php?thread_name=4D444651.8050303%40fultondesigns.co.uk&forum_name=swig-user
 sub complain_about_disabled_languages_not_working
 {
     # Pffffft.
     print "*"x75, "\n";
-    print "  The SWIG build process doesn't actually disable multi-language support.\n";
-    print "   These options are left in, hoping that someday it'll actually work.\n\n";
-    print "  More info:\n";
-    print "    https://sourceforge.net/mailarchive/message.php?msg_id=26967542\n";
-    print "    https://sourceforge.net/mailarchive/message.php?msg_id=26978599\n";
+    print "  The SWIG build process doesn't actually disable other language support.\n";
+    print "   These options are left in, hoping that someday it'll actually work.\n";
     print "*"x75, "\n";
 
     return;
@@ -493,21 +444,15 @@ sub complain_about_disabled_languages_not_working
 # These are used in Build.PL
 #
 
-sub cache_known_vers
-{
-    %known_vers = map { $_ => 1 } @known_vers
-        unless( keys( %known_vers ) );
-
-    return;
-}
-
 sub is_known_ver
 {
     shift;  # ignore first arg, class method
     my $ver = shift;
     return $FALSE unless( defined( $ver ) );
 
-    cache_known_vers();
+    # map and cache
+    %known_vers = map { $_ => 1 } @known_vers
+        unless( keys( %known_vers ) );
 
     return( exists( $known_vers{$ver} ) ? $TRUE : $FALSE );
 }
@@ -521,8 +466,7 @@ sub formatted_known_vers
 {
     my $s = '';
     my $c = 0;
-    cache_known_vers();
-    for my $v ( sort keys( %known_vers ) )
+    for my $v ( MY::Build->known_vers() )
     {
         $s .= '  ' unless( $c % 9 );
         $s .= sprintf "%-8s", $v;
@@ -536,32 +480,6 @@ sub random_ver
     return( $known_vers[rand @known_vers] );
 }
 
-sub write_swig_ver_file
-{
-    shift;  # Get rid of class/object
-    my $ver = shift;
-    $ver = def_swig_ver() unless( defined( $ver ) );
-
-    open my $fh, '>', $SWIG_VER_FILE or return;
-    print $fh $ver;
-    close $fh;
-
-    return;
-}
-
-sub read_swig_ver
-{
-    open my $fh, '<', $SWIG_VER_FILE
-        or return def_swig_ver();
-
-    my $ver = <$fh>;
-    close( $fh );
-    chomp $ver;
-    $ver = def_swig_ver() unless( defined( $ver ) );
-
-    return $ver;
-}
-
 1;
 
 __END__
